import React, { useEffect, useState } from 'react';
import { HiMiniStop, HiVolumeOff, HiVolumeUp } from './icons.js';
function Speech({ text, pitch = 1, rate = 1, volume = 1, lang = '', startBtn = React.createElement(HiVolumeUp, null), pauseBtn = React.createElement(HiVolumeOff, null), stopBtn = React.createElement(HiMiniStop, null), onError = () => alert('Browser not supported! Try some other browser.'), children, props = {} }) {
    const [speechStatus, setSpeechStatus] = useState('stopped');
    function pause() {
        var _a;
        setSpeechStatus('paused');
        (_a = window.speechSynthesis) === null || _a === void 0 ? void 0 : _a.pause();
    }
    function start() {
        const synth = window.speechSynthesis;
        if (!synth)
            return onError();
        setSpeechStatus('started');
        if (synth.paused)
            return synth.resume();
        if (synth.speaking)
            synth.cancel();
        const utterance = new window.SpeechSynthesisUtterance(text === null || text === void 0 ? void 0 : text.replace(/\s/g, ' '));
        utterance.pitch = pitch;
        utterance.rate = rate;
        utterance.volume = volume;
        utterance.lang = lang;
        utterance.onend = () => stop();
        utterance.onerror = () => stop();
        synth.speak(utterance);
    }
    function stop(manual) {
        var _a;
        setSpeechStatus('stopped');
        if (manual)
            (_a = window.speechSynthesis) === null || _a === void 0 ? void 0 : _a.cancel();
    }
    function speech() {
        if (speechStatus === 'started')
            pause();
        else
            start();
    }
    useEffect(() => { var _a; (_a = window.speechSynthesis) === null || _a === void 0 ? void 0 : _a.cancel(); }, []);
    return typeof children === 'function' ? children({ speechStatus, start, pause, stop }) : React.createElement("div", Object.assign({ style: { display: 'flex', columnGap: '1rem' } }, props),
        React.createElement("span", { role: 'button', onClick: speech }, speechStatus === 'started' ? pauseBtn : startBtn),
        stopBtn && React.createElement("span", { role: 'button', onClick: () => stop(true) }, stopBtn));
}
export default Speech;
